# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class SentEmailDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'user_id': 'str',
        'inbox_id': 'str',
        'domain_id': 'str',
        'to': 'list[str]',
        '_from': 'str',
        'sender': 'Sender',
        'recipients': 'EmailRecipients',
        'reply_to': 'str',
        'cc': 'list[str]',
        'bcc': 'list[str]',
        'attachments': 'list[str]',
        'subject': 'str',
        'body_md5_hash': 'str',
        'body': 'str',
        'to_contacts': 'list[str]',
        'to_group': 'str',
        'charset': 'str',
        'is_html': 'bool',
        'sent_at': 'datetime',
        'created_at': 'datetime',
        'pixel_ids': 'list[str]',
        'message_id': 'str',
        'message_ids': 'list[str]',
        'virtual_send': 'bool',
        'template_id': 'str',
        'template_variables': 'dict(str, object)',
        'headers': 'dict(str, str)',
        'thread_id': 'str',
        'body_excerpt': 'str',
        'text_excerpt': 'str',
        'in_reply_to': 'str',
        'favourite': 'bool',
        'size_bytes': 'int',
        'html': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'user_id': 'userId',
        'inbox_id': 'inboxId',
        'domain_id': 'domainId',
        'to': 'to',
        '_from': 'from',
        'sender': 'sender',
        'recipients': 'recipients',
        'reply_to': 'replyTo',
        'cc': 'cc',
        'bcc': 'bcc',
        'attachments': 'attachments',
        'subject': 'subject',
        'body_md5_hash': 'bodyMD5Hash',
        'body': 'body',
        'to_contacts': 'toContacts',
        'to_group': 'toGroup',
        'charset': 'charset',
        'is_html': 'isHTML',
        'sent_at': 'sentAt',
        'created_at': 'createdAt',
        'pixel_ids': 'pixelIds',
        'message_id': 'messageId',
        'message_ids': 'messageIds',
        'virtual_send': 'virtualSend',
        'template_id': 'templateId',
        'template_variables': 'templateVariables',
        'headers': 'headers',
        'thread_id': 'threadId',
        'body_excerpt': 'bodyExcerpt',
        'text_excerpt': 'textExcerpt',
        'in_reply_to': 'inReplyTo',
        'favourite': 'favourite',
        'size_bytes': 'sizeBytes',
        'html': 'html'
    }

    def __init__(self, id=None, user_id=None, inbox_id=None, domain_id=None, to=None, _from=None, sender=None, recipients=None, reply_to=None, cc=None, bcc=None, attachments=None, subject=None, body_md5_hash=None, body=None, to_contacts=None, to_group=None, charset=None, is_html=None, sent_at=None, created_at=None, pixel_ids=None, message_id=None, message_ids=None, virtual_send=None, template_id=None, template_variables=None, headers=None, thread_id=None, body_excerpt=None, text_excerpt=None, in_reply_to=None, favourite=None, size_bytes=None, html=None, local_vars_configuration=None):  # noqa: E501
        """SentEmailDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._user_id = None
        self._inbox_id = None
        self._domain_id = None
        self._to = None
        self.__from = None
        self._sender = None
        self._recipients = None
        self._reply_to = None
        self._cc = None
        self._bcc = None
        self._attachments = None
        self._subject = None
        self._body_md5_hash = None
        self._body = None
        self._to_contacts = None
        self._to_group = None
        self._charset = None
        self._is_html = None
        self._sent_at = None
        self._created_at = None
        self._pixel_ids = None
        self._message_id = None
        self._message_ids = None
        self._virtual_send = None
        self._template_id = None
        self._template_variables = None
        self._headers = None
        self._thread_id = None
        self._body_excerpt = None
        self._text_excerpt = None
        self._in_reply_to = None
        self._favourite = None
        self._size_bytes = None
        self._html = None
        self.discriminator = None

        self.id = id
        self.user_id = user_id
        self.inbox_id = inbox_id
        self.domain_id = domain_id
        self.to = to
        self._from = _from
        self.sender = sender
        self.recipients = recipients
        self.reply_to = reply_to
        self.cc = cc
        self.bcc = bcc
        self.attachments = attachments
        self.subject = subject
        self.body_md5_hash = body_md5_hash
        self.body = body
        self.to_contacts = to_contacts
        self.to_group = to_group
        self.charset = charset
        self.is_html = is_html
        self.sent_at = sent_at
        self.created_at = created_at
        self.pixel_ids = pixel_ids
        self.message_id = message_id
        self.message_ids = message_ids
        self.virtual_send = virtual_send
        self.template_id = template_id
        self.template_variables = template_variables
        self.headers = headers
        self.thread_id = thread_id
        self.body_excerpt = body_excerpt
        self.text_excerpt = text_excerpt
        self.in_reply_to = in_reply_to
        self.favourite = favourite
        self.size_bytes = size_bytes
        if html is not None:
            self.html = html

    @property
    def id(self):
        """Gets the id of this SentEmailDto.  # noqa: E501

        ID of sent email  # noqa: E501

        :return: The id of this SentEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SentEmailDto.

        ID of sent email  # noqa: E501

        :param id: The id of this SentEmailDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this SentEmailDto.  # noqa: E501

        User ID  # noqa: E501

        :return: The user_id of this SentEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this SentEmailDto.

        User ID  # noqa: E501

        :param user_id: The user_id of this SentEmailDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def inbox_id(self):
        """Gets the inbox_id of this SentEmailDto.  # noqa: E501

        Inbox ID email was sent from  # noqa: E501

        :return: The inbox_id of this SentEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._inbox_id

    @inbox_id.setter
    def inbox_id(self, inbox_id):
        """Sets the inbox_id of this SentEmailDto.

        Inbox ID email was sent from  # noqa: E501

        :param inbox_id: The inbox_id of this SentEmailDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and inbox_id is None:  # noqa: E501
            raise ValueError("Invalid value for `inbox_id`, must not be `None`")  # noqa: E501

        self._inbox_id = inbox_id

    @property
    def domain_id(self):
        """Gets the domain_id of this SentEmailDto.  # noqa: E501

        Domain ID  # noqa: E501

        :return: The domain_id of this SentEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._domain_id

    @domain_id.setter
    def domain_id(self, domain_id):
        """Sets the domain_id of this SentEmailDto.

        Domain ID  # noqa: E501

        :param domain_id: The domain_id of this SentEmailDto.  # noqa: E501
        :type: str
        """

        self._domain_id = domain_id

    @property
    def to(self):
        """Gets the to of this SentEmailDto.  # noqa: E501

        Recipients email was sent to  # noqa: E501

        :return: The to of this SentEmailDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this SentEmailDto.

        Recipients email was sent to  # noqa: E501

        :param to: The to of this SentEmailDto.  # noqa: E501
        :type: list[str]
        """

        self._to = to

    @property
    def _from(self):
        """Gets the _from of this SentEmailDto.  # noqa: E501

        Sent from address  # noqa: E501

        :return: The _from of this SentEmailDto.  # noqa: E501
        :rtype: str
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this SentEmailDto.

        Sent from address  # noqa: E501

        :param _from: The _from of this SentEmailDto.  # noqa: E501
        :type: str
        """

        self.__from = _from

    @property
    def sender(self):
        """Gets the sender of this SentEmailDto.  # noqa: E501


        :return: The sender of this SentEmailDto.  # noqa: E501
        :rtype: Sender
        """
        return self._sender

    @sender.setter
    def sender(self, sender):
        """Sets the sender of this SentEmailDto.


        :param sender: The sender of this SentEmailDto.  # noqa: E501
        :type: Sender
        """

        self._sender = sender

    @property
    def recipients(self):
        """Gets the recipients of this SentEmailDto.  # noqa: E501


        :return: The recipients of this SentEmailDto.  # noqa: E501
        :rtype: EmailRecipients
        """
        return self._recipients

    @recipients.setter
    def recipients(self, recipients):
        """Sets the recipients of this SentEmailDto.


        :param recipients: The recipients of this SentEmailDto.  # noqa: E501
        :type: EmailRecipients
        """

        self._recipients = recipients

    @property
    def reply_to(self):
        """Gets the reply_to of this SentEmailDto.  # noqa: E501


        :return: The reply_to of this SentEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._reply_to

    @reply_to.setter
    def reply_to(self, reply_to):
        """Sets the reply_to of this SentEmailDto.


        :param reply_to: The reply_to of this SentEmailDto.  # noqa: E501
        :type: str
        """

        self._reply_to = reply_to

    @property
    def cc(self):
        """Gets the cc of this SentEmailDto.  # noqa: E501


        :return: The cc of this SentEmailDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._cc

    @cc.setter
    def cc(self, cc):
        """Sets the cc of this SentEmailDto.


        :param cc: The cc of this SentEmailDto.  # noqa: E501
        :type: list[str]
        """

        self._cc = cc

    @property
    def bcc(self):
        """Gets the bcc of this SentEmailDto.  # noqa: E501


        :return: The bcc of this SentEmailDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._bcc

    @bcc.setter
    def bcc(self, bcc):
        """Sets the bcc of this SentEmailDto.


        :param bcc: The bcc of this SentEmailDto.  # noqa: E501
        :type: list[str]
        """

        self._bcc = bcc

    @property
    def attachments(self):
        """Gets the attachments of this SentEmailDto.  # noqa: E501

        Array of IDs of attachments that were sent with this email  # noqa: E501

        :return: The attachments of this SentEmailDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._attachments

    @attachments.setter
    def attachments(self, attachments):
        """Sets the attachments of this SentEmailDto.

        Array of IDs of attachments that were sent with this email  # noqa: E501

        :param attachments: The attachments of this SentEmailDto.  # noqa: E501
        :type: list[str]
        """

        self._attachments = attachments

    @property
    def subject(self):
        """Gets the subject of this SentEmailDto.  # noqa: E501


        :return: The subject of this SentEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this SentEmailDto.


        :param subject: The subject of this SentEmailDto.  # noqa: E501
        :type: str
        """

        self._subject = subject

    @property
    def body_md5_hash(self):
        """Gets the body_md5_hash of this SentEmailDto.  # noqa: E501

        MD5 Hash  # noqa: E501

        :return: The body_md5_hash of this SentEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._body_md5_hash

    @body_md5_hash.setter
    def body_md5_hash(self, body_md5_hash):
        """Sets the body_md5_hash of this SentEmailDto.

        MD5 Hash  # noqa: E501

        :param body_md5_hash: The body_md5_hash of this SentEmailDto.  # noqa: E501
        :type: str
        """

        self._body_md5_hash = body_md5_hash

    @property
    def body(self):
        """Gets the body of this SentEmailDto.  # noqa: E501

        Sent email body  # noqa: E501

        :return: The body of this SentEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this SentEmailDto.

        Sent email body  # noqa: E501

        :param body: The body of this SentEmailDto.  # noqa: E501
        :type: str
        """

        self._body = body

    @property
    def to_contacts(self):
        """Gets the to_contacts of this SentEmailDto.  # noqa: E501


        :return: The to_contacts of this SentEmailDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._to_contacts

    @to_contacts.setter
    def to_contacts(self, to_contacts):
        """Sets the to_contacts of this SentEmailDto.


        :param to_contacts: The to_contacts of this SentEmailDto.  # noqa: E501
        :type: list[str]
        """

        self._to_contacts = to_contacts

    @property
    def to_group(self):
        """Gets the to_group of this SentEmailDto.  # noqa: E501


        :return: The to_group of this SentEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._to_group

    @to_group.setter
    def to_group(self, to_group):
        """Sets the to_group of this SentEmailDto.


        :param to_group: The to_group of this SentEmailDto.  # noqa: E501
        :type: str
        """

        self._to_group = to_group

    @property
    def charset(self):
        """Gets the charset of this SentEmailDto.  # noqa: E501


        :return: The charset of this SentEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._charset

    @charset.setter
    def charset(self, charset):
        """Sets the charset of this SentEmailDto.


        :param charset: The charset of this SentEmailDto.  # noqa: E501
        :type: str
        """

        self._charset = charset

    @property
    def is_html(self):
        """Gets the is_html of this SentEmailDto.  # noqa: E501


        :return: The is_html of this SentEmailDto.  # noqa: E501
        :rtype: bool
        """
        return self._is_html

    @is_html.setter
    def is_html(self, is_html):
        """Sets the is_html of this SentEmailDto.


        :param is_html: The is_html of this SentEmailDto.  # noqa: E501
        :type: bool
        """

        self._is_html = is_html

    @property
    def sent_at(self):
        """Gets the sent_at of this SentEmailDto.  # noqa: E501


        :return: The sent_at of this SentEmailDto.  # noqa: E501
        :rtype: datetime
        """
        return self._sent_at

    @sent_at.setter
    def sent_at(self, sent_at):
        """Sets the sent_at of this SentEmailDto.


        :param sent_at: The sent_at of this SentEmailDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and sent_at is None:  # noqa: E501
            raise ValueError("Invalid value for `sent_at`, must not be `None`")  # noqa: E501

        self._sent_at = sent_at

    @property
    def created_at(self):
        """Gets the created_at of this SentEmailDto.  # noqa: E501


        :return: The created_at of this SentEmailDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this SentEmailDto.


        :param created_at: The created_at of this SentEmailDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def pixel_ids(self):
        """Gets the pixel_ids of this SentEmailDto.  # noqa: E501


        :return: The pixel_ids of this SentEmailDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._pixel_ids

    @pixel_ids.setter
    def pixel_ids(self, pixel_ids):
        """Sets the pixel_ids of this SentEmailDto.


        :param pixel_ids: The pixel_ids of this SentEmailDto.  # noqa: E501
        :type: list[str]
        """

        self._pixel_ids = pixel_ids

    @property
    def message_id(self):
        """Gets the message_id of this SentEmailDto.  # noqa: E501

        RFC 5322 Message-ID header value without angle brackets.  # noqa: E501

        :return: The message_id of this SentEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._message_id

    @message_id.setter
    def message_id(self, message_id):
        """Sets the message_id of this SentEmailDto.

        RFC 5322 Message-ID header value without angle brackets.  # noqa: E501

        :param message_id: The message_id of this SentEmailDto.  # noqa: E501
        :type: str
        """

        self._message_id = message_id

    @property
    def message_ids(self):
        """Gets the message_ids of this SentEmailDto.  # noqa: E501


        :return: The message_ids of this SentEmailDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._message_ids

    @message_ids.setter
    def message_ids(self, message_ids):
        """Sets the message_ids of this SentEmailDto.


        :param message_ids: The message_ids of this SentEmailDto.  # noqa: E501
        :type: list[str]
        """

        self._message_ids = message_ids

    @property
    def virtual_send(self):
        """Gets the virtual_send of this SentEmailDto.  # noqa: E501


        :return: The virtual_send of this SentEmailDto.  # noqa: E501
        :rtype: bool
        """
        return self._virtual_send

    @virtual_send.setter
    def virtual_send(self, virtual_send):
        """Sets the virtual_send of this SentEmailDto.


        :param virtual_send: The virtual_send of this SentEmailDto.  # noqa: E501
        :type: bool
        """

        self._virtual_send = virtual_send

    @property
    def template_id(self):
        """Gets the template_id of this SentEmailDto.  # noqa: E501


        :return: The template_id of this SentEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._template_id

    @template_id.setter
    def template_id(self, template_id):
        """Sets the template_id of this SentEmailDto.


        :param template_id: The template_id of this SentEmailDto.  # noqa: E501
        :type: str
        """

        self._template_id = template_id

    @property
    def template_variables(self):
        """Gets the template_variables of this SentEmailDto.  # noqa: E501


        :return: The template_variables of this SentEmailDto.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._template_variables

    @template_variables.setter
    def template_variables(self, template_variables):
        """Sets the template_variables of this SentEmailDto.


        :param template_variables: The template_variables of this SentEmailDto.  # noqa: E501
        :type: dict(str, object)
        """

        self._template_variables = template_variables

    @property
    def headers(self):
        """Gets the headers of this SentEmailDto.  # noqa: E501


        :return: The headers of this SentEmailDto.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._headers

    @headers.setter
    def headers(self, headers):
        """Sets the headers of this SentEmailDto.


        :param headers: The headers of this SentEmailDto.  # noqa: E501
        :type: dict(str, str)
        """

        self._headers = headers

    @property
    def thread_id(self):
        """Gets the thread_id of this SentEmailDto.  # noqa: E501

        MailSlurp thread ID for email chain that enables lookup for In-Reply-To and References fields.  # noqa: E501

        :return: The thread_id of this SentEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._thread_id

    @thread_id.setter
    def thread_id(self, thread_id):
        """Sets the thread_id of this SentEmailDto.

        MailSlurp thread ID for email chain that enables lookup for In-Reply-To and References fields.  # noqa: E501

        :param thread_id: The thread_id of this SentEmailDto.  # noqa: E501
        :type: str
        """

        self._thread_id = thread_id

    @property
    def body_excerpt(self):
        """Gets the body_excerpt of this SentEmailDto.  # noqa: E501

        An excerpt of the body of the email message for quick preview. Takes HTML content part if exists falls back to TEXT content part if not  # noqa: E501

        :return: The body_excerpt of this SentEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._body_excerpt

    @body_excerpt.setter
    def body_excerpt(self, body_excerpt):
        """Sets the body_excerpt of this SentEmailDto.

        An excerpt of the body of the email message for quick preview. Takes HTML content part if exists falls back to TEXT content part if not  # noqa: E501

        :param body_excerpt: The body_excerpt of this SentEmailDto.  # noqa: E501
        :type: str
        """

        self._body_excerpt = body_excerpt

    @property
    def text_excerpt(self):
        """Gets the text_excerpt of this SentEmailDto.  # noqa: E501

        An excerpt of the body of the email message for quick preview. Takes TEXT content part if exists  # noqa: E501

        :return: The text_excerpt of this SentEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._text_excerpt

    @text_excerpt.setter
    def text_excerpt(self, text_excerpt):
        """Sets the text_excerpt of this SentEmailDto.

        An excerpt of the body of the email message for quick preview. Takes TEXT content part if exists  # noqa: E501

        :param text_excerpt: The text_excerpt of this SentEmailDto.  # noqa: E501
        :type: str
        """

        self._text_excerpt = text_excerpt

    @property
    def in_reply_to(self):
        """Gets the in_reply_to of this SentEmailDto.  # noqa: E501

        Parsed value of In-Reply-To header. A Message-ID in a thread.  # noqa: E501

        :return: The in_reply_to of this SentEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._in_reply_to

    @in_reply_to.setter
    def in_reply_to(self, in_reply_to):
        """Sets the in_reply_to of this SentEmailDto.

        Parsed value of In-Reply-To header. A Message-ID in a thread.  # noqa: E501

        :param in_reply_to: The in_reply_to of this SentEmailDto.  # noqa: E501
        :type: str
        """

        self._in_reply_to = in_reply_to

    @property
    def favourite(self):
        """Gets the favourite of this SentEmailDto.  # noqa: E501

        Is email favourited  # noqa: E501

        :return: The favourite of this SentEmailDto.  # noqa: E501
        :rtype: bool
        """
        return self._favourite

    @favourite.setter
    def favourite(self, favourite):
        """Sets the favourite of this SentEmailDto.

        Is email favourited  # noqa: E501

        :param favourite: The favourite of this SentEmailDto.  # noqa: E501
        :type: bool
        """

        self._favourite = favourite

    @property
    def size_bytes(self):
        """Gets the size_bytes of this SentEmailDto.  # noqa: E501

        Size of raw email message in bytes  # noqa: E501

        :return: The size_bytes of this SentEmailDto.  # noqa: E501
        :rtype: int
        """
        return self._size_bytes

    @size_bytes.setter
    def size_bytes(self, size_bytes):
        """Sets the size_bytes of this SentEmailDto.

        Size of raw email message in bytes  # noqa: E501

        :param size_bytes: The size_bytes of this SentEmailDto.  # noqa: E501
        :type: int
        """

        self._size_bytes = size_bytes

    @property
    def html(self):
        """Gets the html of this SentEmailDto.  # noqa: E501


        :return: The html of this SentEmailDto.  # noqa: E501
        :rtype: bool
        """
        return self._html

    @html.setter
    def html(self, html):
        """Sets the html of this SentEmailDto.


        :param html: The html of this SentEmailDto.  # noqa: E501
        :type: bool
        """

        self._html = html

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SentEmailDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SentEmailDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DeliverabilityFailureHotspotsDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'since': 'datetime',
        'before': 'datetime',
        'scope': 'str',
        'entity_hotspots': 'list[DeliverabilityFailureEntityHotspotDto]',
        'phone_dimension_hotspots': 'list[DeliverabilityFailurePhoneDimensionHotspotDto]'
    }

    attribute_map = {
        'since': 'since',
        'before': 'before',
        'scope': 'scope',
        'entity_hotspots': 'entityHotspots',
        'phone_dimension_hotspots': 'phoneDimensionHotspots'
    }

    def __init__(self, since=None, before=None, scope=None, entity_hotspots=None, phone_dimension_hotspots=None, local_vars_configuration=None):  # noqa: E501
        """DeliverabilityFailureHotspotsDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._since = None
        self._before = None
        self._scope = None
        self._entity_hotspots = None
        self._phone_dimension_hotspots = None
        self.discriminator = None

        self.since = since
        self.before = before
        self.scope = scope
        self.entity_hotspots = entity_hotspots
        self.phone_dimension_hotspots = phone_dimension_hotspots

    @property
    def since(self):
        """Gets the since of this DeliverabilityFailureHotspotsDto.  # noqa: E501


        :return: The since of this DeliverabilityFailureHotspotsDto.  # noqa: E501
        :rtype: datetime
        """
        return self._since

    @since.setter
    def since(self, since):
        """Sets the since of this DeliverabilityFailureHotspotsDto.


        :param since: The since of this DeliverabilityFailureHotspotsDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and since is None:  # noqa: E501
            raise ValueError("Invalid value for `since`, must not be `None`")  # noqa: E501

        self._since = since

    @property
    def before(self):
        """Gets the before of this DeliverabilityFailureHotspotsDto.  # noqa: E501


        :return: The before of this DeliverabilityFailureHotspotsDto.  # noqa: E501
        :rtype: datetime
        """
        return self._before

    @before.setter
    def before(self, before):
        """Sets the before of this DeliverabilityFailureHotspotsDto.


        :param before: The before of this DeliverabilityFailureHotspotsDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and before is None:  # noqa: E501
            raise ValueError("Invalid value for `before`, must not be `None`")  # noqa: E501

        self._before = before

    @property
    def scope(self):
        """Gets the scope of this DeliverabilityFailureHotspotsDto.  # noqa: E501


        :return: The scope of this DeliverabilityFailureHotspotsDto.  # noqa: E501
        :rtype: str
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this DeliverabilityFailureHotspotsDto.


        :param scope: The scope of this DeliverabilityFailureHotspotsDto.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"INBOX", "PHONE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and scope not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `scope` ({0}), must be one of {1}"  # noqa: E501
                .format(scope, allowed_values)
            )

        self._scope = scope

    @property
    def entity_hotspots(self):
        """Gets the entity_hotspots of this DeliverabilityFailureHotspotsDto.  # noqa: E501


        :return: The entity_hotspots of this DeliverabilityFailureHotspotsDto.  # noqa: E501
        :rtype: list[DeliverabilityFailureEntityHotspotDto]
        """
        return self._entity_hotspots

    @entity_hotspots.setter
    def entity_hotspots(self, entity_hotspots):
        """Sets the entity_hotspots of this DeliverabilityFailureHotspotsDto.


        :param entity_hotspots: The entity_hotspots of this DeliverabilityFailureHotspotsDto.  # noqa: E501
        :type: list[DeliverabilityFailureEntityHotspotDto]
        """
        if self.local_vars_configuration.client_side_validation and entity_hotspots is None:  # noqa: E501
            raise ValueError("Invalid value for `entity_hotspots`, must not be `None`")  # noqa: E501

        self._entity_hotspots = entity_hotspots

    @property
    def phone_dimension_hotspots(self):
        """Gets the phone_dimension_hotspots of this DeliverabilityFailureHotspotsDto.  # noqa: E501


        :return: The phone_dimension_hotspots of this DeliverabilityFailureHotspotsDto.  # noqa: E501
        :rtype: list[DeliverabilityFailurePhoneDimensionHotspotDto]
        """
        return self._phone_dimension_hotspots

    @phone_dimension_hotspots.setter
    def phone_dimension_hotspots(self, phone_dimension_hotspots):
        """Sets the phone_dimension_hotspots of this DeliverabilityFailureHotspotsDto.


        :param phone_dimension_hotspots: The phone_dimension_hotspots of this DeliverabilityFailureHotspotsDto.  # noqa: E501
        :type: list[DeliverabilityFailurePhoneDimensionHotspotDto]
        """
        if self.local_vars_configuration.client_side_validation and phone_dimension_hotspots is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_dimension_hotspots`, must not be `None`")  # noqa: E501

        self._phone_dimension_hotspots = phone_dimension_hotspots

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeliverabilityFailureHotspotsDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeliverabilityFailureHotspotsDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mailslurp_client
from mailslurp_client.models.email_audit_comparison_dto import EmailAuditComparisonDto  # noqa: E501
from mailslurp_client.rest import ApiException

class TestEmailAuditComparisonDto(unittest.TestCase):
    """EmailAuditComparisonDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test EmailAuditComparisonDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = mailslurp_client.models.email_audit_comparison_dto.EmailAuditComparisonDto()  # noqa: E501
        if include_optional :
            return EmailAuditComparisonDto(
                baseline = mailslurp_client.models.email_audit_dto.EmailAuditDto(
                    id = '0', 
                    user_id = '0', 
                    email_id = '0', 
                    from_address = '0', 
                    recipient = '0', 
                    subject = '0', 
                    analysis = mailslurp_client.models.email_audit_analysis_result.EmailAuditAnalysisResult(
                        status = 'HEALTHY', 
                        health_score = 56, 
                        total_checks = 56, 
                        passing_checks = 56, 
                        failing_checks = 56, 
                        detected_links = 56, 
                        checked_links = 56, 
                        detected_images = 56, 
                        checked_images = 56, 
                        link_issue_count = 56, 
                        image_issue_count = 56, 
                        spelling_issue_count = 56, 
                        broken_links = [
                            mailslurp_client.models.email_audit_url_issue.EmailAuditUrlIssue(
                                url = '0', 
                                status_code = 56, 
                                message = '0', )
                            ], 
                        broken_images = [
                            mailslurp_client.models.email_audit_url_issue.EmailAuditUrlIssue(
                                url = '0', 
                                status_code = 56, 
                                message = '0', )
                            ], 
                        spelling_issues = [
                            mailslurp_client.models.email_audit_spelling_issue.EmailAuditSpellingIssue(
                                group = '0', 
                                suggestion = '0', 
                                severity = 'Warning', 
                                message = '0', )
                            ], 
                        compatibility_warning_count = 56, 
                        compatibility_not_supported_count = 56, 
                        compatibility_unknown_count = 56, 
                        feature_support = mailslurp_client.models.email_feature_support_result.EmailFeatureSupportResult(
                            names = mailslurp_client.models.email_feature_names.EmailFeatureNames(
                                family = [
                                    mailslurp_client.models.email_feature_family_name.EmailFeatureFamilyName(
                                        slug = 'aol', 
                                        name = '0', )
                                    ], 
                                platform = [
                                    mailslurp_client.models.email_feature_platform_name.EmailFeaturePlatformName(
                                        slug = 'android', 
                                        name = '0', )
                                    ], 
                                category = [
                                    mailslurp_client.models.email_feature_category_name.EmailFeatureCategoryName(
                                        slug = 'css', 
                                        name = '0', )
                                    ], ), 
                            detected_features = [
                                'amp'
                                ], 
                            feature_overviews = [
                                mailslurp_client.models.email_feature_overview.EmailFeatureOverview(
                                    feature = 'amp', 
                                    title = '0', 
                                    description = '0', 
                                    notes = '0', 
                                    notes_numbers = {
                                        'key' : '0'
                                        }, 
                                    feature_statistics = [
                                        mailslurp_client.models.email_feature_family_statistics.EmailFeatureFamilyStatistics(
                                            feature = 'amp', 
                                            family = 'aol', 
                                            platforms = [
                                                mailslurp_client.models.email_feature_platform_statistics.EmailFeaturePlatformStatistics(
                                                    platform = 'android', 
                                                    versions = [
                                                        mailslurp_client.models.email_feature_version_statistics.EmailFeatureVersionStatistics(
                                                            version = '0', 
                                                            support_flags = mailslurp_client.models.email_feature_support_flags.EmailFeatureSupportFlags(
                                                                status = 'SUPPORTED', 
                                                                notes = [
                                                                    '0'
                                                                    ], ), )
                                                        ], )
                                                ], )
                                        ], 
                                    statuses = [
                                        'SUPPORTED'
                                        ], )
                                ], 
                            feature_percentages = [
                                mailslurp_client.models.email_feature_support_status_percentage.EmailFeatureSupportStatusPercentage(
                                    status = 'SUPPORTED', 
                                    percentage = 1.337, )
                                ], ), 
                        html_error_count = 56, 
                        html_warning_count = 56, 
                        html_info_count = 56, 
                        html_validation = mailslurp_client.models.html_validation_result.HTMLValidationResult(
                            is_valid = True, 
                            infos = [
                                mailslurp_client.models.validation_message.ValidationMessage(
                                    line_number = 56, 
                                    message = '0', )
                                ], 
                            errors = [
                                mailslurp_client.models.validation_message.ValidationMessage(
                                    line_number = 56, 
                                    message = '0', )
                                ], 
                            warnings = [
                                mailslurp_client.models.validation_message.ValidationMessage(
                                    line_number = 56, 
                                    message = '0', )
                                ], ), 
                        reputation_failure_count = 56, 
                        attachment_mention_issue_count = 56, 
                        external_check_skipped_count = 56, 
                        insights = [
                            '0'
                            ], 
                        error_message = '0', ), 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                current = mailslurp_client.models.email_audit_dto.EmailAuditDto(
                    id = '0', 
                    user_id = '0', 
                    email_id = '0', 
                    from_address = '0', 
                    recipient = '0', 
                    subject = '0', 
                    analysis = mailslurp_client.models.email_audit_analysis_result.EmailAuditAnalysisResult(
                        status = 'HEALTHY', 
                        health_score = 56, 
                        total_checks = 56, 
                        passing_checks = 56, 
                        failing_checks = 56, 
                        detected_links = 56, 
                        checked_links = 56, 
                        detected_images = 56, 
                        checked_images = 56, 
                        link_issue_count = 56, 
                        image_issue_count = 56, 
                        spelling_issue_count = 56, 
                        broken_links = [
                            mailslurp_client.models.email_audit_url_issue.EmailAuditUrlIssue(
                                url = '0', 
                                status_code = 56, 
                                message = '0', )
                            ], 
                        broken_images = [
                            mailslurp_client.models.email_audit_url_issue.EmailAuditUrlIssue(
                                url = '0', 
                                status_code = 56, 
                                message = '0', )
                            ], 
                        spelling_issues = [
                            mailslurp_client.models.email_audit_spelling_issue.EmailAuditSpellingIssue(
                                group = '0', 
                                suggestion = '0', 
                                severity = 'Warning', 
                                message = '0', )
                            ], 
                        compatibility_warning_count = 56, 
                        compatibility_not_supported_count = 56, 
                        compatibility_unknown_count = 56, 
                        feature_support = mailslurp_client.models.email_feature_support_result.EmailFeatureSupportResult(
                            names = mailslurp_client.models.email_feature_names.EmailFeatureNames(
                                family = [
                                    mailslurp_client.models.email_feature_family_name.EmailFeatureFamilyName(
                                        slug = 'aol', 
                                        name = '0', )
                                    ], 
                                platform = [
                                    mailslurp_client.models.email_feature_platform_name.EmailFeaturePlatformName(
                                        slug = 'android', 
                                        name = '0', )
                                    ], 
                                category = [
                                    mailslurp_client.models.email_feature_category_name.EmailFeatureCategoryName(
                                        slug = 'css', 
                                        name = '0', )
                                    ], ), 
                            detected_features = [
                                'amp'
                                ], 
                            feature_overviews = [
                                mailslurp_client.models.email_feature_overview.EmailFeatureOverview(
                                    feature = 'amp', 
                                    title = '0', 
                                    description = '0', 
                                    notes = '0', 
                                    notes_numbers = {
                                        'key' : '0'
                                        }, 
                                    feature_statistics = [
                                        mailslurp_client.models.email_feature_family_statistics.EmailFeatureFamilyStatistics(
                                            feature = 'amp', 
                                            family = 'aol', 
                                            platforms = [
                                                mailslurp_client.models.email_feature_platform_statistics.EmailFeaturePlatformStatistics(
                                                    platform = 'android', 
                                                    versions = [
                                                        mailslurp_client.models.email_feature_version_statistics.EmailFeatureVersionStatistics(
                                                            version = '0', 
                                                            support_flags = mailslurp_client.models.email_feature_support_flags.EmailFeatureSupportFlags(
                                                                status = 'SUPPORTED', 
                                                                notes = [
                                                                    '0'
                                                                    ], ), )
                                                        ], )
                                                ], )
                                        ], 
                                    statuses = [
                                        'SUPPORTED'
                                        ], )
                                ], 
                            feature_percentages = [
                                mailslurp_client.models.email_feature_support_status_percentage.EmailFeatureSupportStatusPercentage(
                                    status = 'SUPPORTED', 
                                    percentage = 1.337, )
                                ], ), 
                        html_error_count = 56, 
                        html_warning_count = 56, 
                        html_info_count = 56, 
                        html_validation = mailslurp_client.models.html_validation_result.HTMLValidationResult(
                            is_valid = True, 
                            infos = [
                                mailslurp_client.models.validation_message.ValidationMessage(
                                    line_number = 56, 
                                    message = '0', )
                                ], 
                            errors = [
                                mailslurp_client.models.validation_message.ValidationMessage(
                                    line_number = 56, 
                                    message = '0', )
                                ], 
                            warnings = [
                                mailslurp_client.models.validation_message.ValidationMessage(
                                    line_number = 56, 
                                    message = '0', )
                                ], ), 
                        reputation_failure_count = 56, 
                        attachment_mention_issue_count = 56, 
                        external_check_skipped_count = 56, 
                        insights = [
                            '0'
                            ], 
                        error_message = '0', ), 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                health_score_delta = 56, 
                status_changed = True, 
                broken_link_delta = 56, 
                broken_image_delta = 56, 
                spelling_issue_delta = 56, 
                html_error_delta = 56, 
                html_warning_delta = 56, 
                compatibility_warning_delta = 56, 
                compatibility_not_supported_delta = 56, 
                reputation_failure_delta = 56, 
                attachment_mention_issue_delta = 56, 
                added_insights = [
                    '0'
                    ], 
                removed_insights = [
                    '0'
                    ]
            )
        else :
            return EmailAuditComparisonDto(
                baseline = mailslurp_client.models.email_audit_dto.EmailAuditDto(
                    id = '0', 
                    user_id = '0', 
                    email_id = '0', 
                    from_address = '0', 
                    recipient = '0', 
                    subject = '0', 
                    analysis = mailslurp_client.models.email_audit_analysis_result.EmailAuditAnalysisResult(
                        status = 'HEALTHY', 
                        health_score = 56, 
                        total_checks = 56, 
                        passing_checks = 56, 
                        failing_checks = 56, 
                        detected_links = 56, 
                        checked_links = 56, 
                        detected_images = 56, 
                        checked_images = 56, 
                        link_issue_count = 56, 
                        image_issue_count = 56, 
                        spelling_issue_count = 56, 
                        broken_links = [
                            mailslurp_client.models.email_audit_url_issue.EmailAuditUrlIssue(
                                url = '0', 
                                status_code = 56, 
                                message = '0', )
                            ], 
                        broken_images = [
                            mailslurp_client.models.email_audit_url_issue.EmailAuditUrlIssue(
                                url = '0', 
                                status_code = 56, 
                                message = '0', )
                            ], 
                        spelling_issues = [
                            mailslurp_client.models.email_audit_spelling_issue.EmailAuditSpellingIssue(
                                group = '0', 
                                suggestion = '0', 
                                severity = 'Warning', 
                                message = '0', )
                            ], 
                        compatibility_warning_count = 56, 
                        compatibility_not_supported_count = 56, 
                        compatibility_unknown_count = 56, 
                        feature_support = mailslurp_client.models.email_feature_support_result.EmailFeatureSupportResult(
                            names = mailslurp_client.models.email_feature_names.EmailFeatureNames(
                                family = [
                                    mailslurp_client.models.email_feature_family_name.EmailFeatureFamilyName(
                                        slug = 'aol', 
                                        name = '0', )
                                    ], 
                                platform = [
                                    mailslurp_client.models.email_feature_platform_name.EmailFeaturePlatformName(
                                        slug = 'android', 
                                        name = '0', )
                                    ], 
                                category = [
                                    mailslurp_client.models.email_feature_category_name.EmailFeatureCategoryName(
                                        slug = 'css', 
                                        name = '0', )
                                    ], ), 
                            detected_features = [
                                'amp'
                                ], 
                            feature_overviews = [
                                mailslurp_client.models.email_feature_overview.EmailFeatureOverview(
                                    feature = 'amp', 
                                    title = '0', 
                                    description = '0', 
                                    notes = '0', 
                                    notes_numbers = {
                                        'key' : '0'
                                        }, 
                                    feature_statistics = [
                                        mailslurp_client.models.email_feature_family_statistics.EmailFeatureFamilyStatistics(
                                            feature = 'amp', 
                                            family = 'aol', 
                                            platforms = [
                                                mailslurp_client.models.email_feature_platform_statistics.EmailFeaturePlatformStatistics(
                                                    platform = 'android', 
                                                    versions = [
                                                        mailslurp_client.models.email_feature_version_statistics.EmailFeatureVersionStatistics(
                                                            version = '0', 
                                                            support_flags = mailslurp_client.models.email_feature_support_flags.EmailFeatureSupportFlags(
                                                                status = 'SUPPORTED', 
                                                                notes = [
                                                                    '0'
                                                                    ], ), )
                                                        ], )
                                                ], )
                                        ], 
                                    statuses = [
                                        'SUPPORTED'
                                        ], )
                                ], 
                            feature_percentages = [
                                mailslurp_client.models.email_feature_support_status_percentage.EmailFeatureSupportStatusPercentage(
                                    status = 'SUPPORTED', 
                                    percentage = 1.337, )
                                ], ), 
                        html_error_count = 56, 
                        html_warning_count = 56, 
                        html_info_count = 56, 
                        html_validation = mailslurp_client.models.html_validation_result.HTMLValidationResult(
                            is_valid = True, 
                            infos = [
                                mailslurp_client.models.validation_message.ValidationMessage(
                                    line_number = 56, 
                                    message = '0', )
                                ], 
                            errors = [
                                mailslurp_client.models.validation_message.ValidationMessage(
                                    line_number = 56, 
                                    message = '0', )
                                ], 
                            warnings = [
                                mailslurp_client.models.validation_message.ValidationMessage(
                                    line_number = 56, 
                                    message = '0', )
                                ], ), 
                        reputation_failure_count = 56, 
                        attachment_mention_issue_count = 56, 
                        external_check_skipped_count = 56, 
                        insights = [
                            '0'
                            ], 
                        error_message = '0', ), 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                current = mailslurp_client.models.email_audit_dto.EmailAuditDto(
                    id = '0', 
                    user_id = '0', 
                    email_id = '0', 
                    from_address = '0', 
                    recipient = '0', 
                    subject = '0', 
                    analysis = mailslurp_client.models.email_audit_analysis_result.EmailAuditAnalysisResult(
                        status = 'HEALTHY', 
                        health_score = 56, 
                        total_checks = 56, 
                        passing_checks = 56, 
                        failing_checks = 56, 
                        detected_links = 56, 
                        checked_links = 56, 
                        detected_images = 56, 
                        checked_images = 56, 
                        link_issue_count = 56, 
                        image_issue_count = 56, 
                        spelling_issue_count = 56, 
                        broken_links = [
                            mailslurp_client.models.email_audit_url_issue.EmailAuditUrlIssue(
                                url = '0', 
                                status_code = 56, 
                                message = '0', )
                            ], 
                        broken_images = [
                            mailslurp_client.models.email_audit_url_issue.EmailAuditUrlIssue(
                                url = '0', 
                                status_code = 56, 
                                message = '0', )
                            ], 
                        spelling_issues = [
                            mailslurp_client.models.email_audit_spelling_issue.EmailAuditSpellingIssue(
                                group = '0', 
                                suggestion = '0', 
                                severity = 'Warning', 
                                message = '0', )
                            ], 
                        compatibility_warning_count = 56, 
                        compatibility_not_supported_count = 56, 
                        compatibility_unknown_count = 56, 
                        feature_support = mailslurp_client.models.email_feature_support_result.EmailFeatureSupportResult(
                            names = mailslurp_client.models.email_feature_names.EmailFeatureNames(
                                family = [
                                    mailslurp_client.models.email_feature_family_name.EmailFeatureFamilyName(
                                        slug = 'aol', 
                                        name = '0', )
                                    ], 
                                platform = [
                                    mailslurp_client.models.email_feature_platform_name.EmailFeaturePlatformName(
                                        slug = 'android', 
                                        name = '0', )
                                    ], 
                                category = [
                                    mailslurp_client.models.email_feature_category_name.EmailFeatureCategoryName(
                                        slug = 'css', 
                                        name = '0', )
                                    ], ), 
                            detected_features = [
                                'amp'
                                ], 
                            feature_overviews = [
                                mailslurp_client.models.email_feature_overview.EmailFeatureOverview(
                                    feature = 'amp', 
                                    title = '0', 
                                    description = '0', 
                                    notes = '0', 
                                    notes_numbers = {
                                        'key' : '0'
                                        }, 
                                    feature_statistics = [
                                        mailslurp_client.models.email_feature_family_statistics.EmailFeatureFamilyStatistics(
                                            feature = 'amp', 
                                            family = 'aol', 
                                            platforms = [
                                                mailslurp_client.models.email_feature_platform_statistics.EmailFeaturePlatformStatistics(
                                                    platform = 'android', 
                                                    versions = [
                                                        mailslurp_client.models.email_feature_version_statistics.EmailFeatureVersionStatistics(
                                                            version = '0', 
                                                            support_flags = mailslurp_client.models.email_feature_support_flags.EmailFeatureSupportFlags(
                                                                status = 'SUPPORTED', 
                                                                notes = [
                                                                    '0'
                                                                    ], ), )
                                                        ], )
                                                ], )
                                        ], 
                                    statuses = [
                                        'SUPPORTED'
                                        ], )
                                ], 
                            feature_percentages = [
                                mailslurp_client.models.email_feature_support_status_percentage.EmailFeatureSupportStatusPercentage(
                                    status = 'SUPPORTED', 
                                    percentage = 1.337, )
                                ], ), 
                        html_error_count = 56, 
                        html_warning_count = 56, 
                        html_info_count = 56, 
                        html_validation = mailslurp_client.models.html_validation_result.HTMLValidationResult(
                            is_valid = True, 
                            infos = [
                                mailslurp_client.models.validation_message.ValidationMessage(
                                    line_number = 56, 
                                    message = '0', )
                                ], 
                            errors = [
                                mailslurp_client.models.validation_message.ValidationMessage(
                                    line_number = 56, 
                                    message = '0', )
                                ], 
                            warnings = [
                                mailslurp_client.models.validation_message.ValidationMessage(
                                    line_number = 56, 
                                    message = '0', )
                                ], ), 
                        reputation_failure_count = 56, 
                        attachment_mention_issue_count = 56, 
                        external_check_skipped_count = 56, 
                        insights = [
                            '0'
                            ], 
                        error_message = '0', ), 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                health_score_delta = 56,
                status_changed = True,
                broken_link_delta = 56,
                broken_image_delta = 56,
                spelling_issue_delta = 56,
                html_error_delta = 56,
                html_warning_delta = 56,
                compatibility_warning_delta = 56,
                compatibility_not_supported_delta = 56,
                reputation_failure_delta = 56,
                attachment_mention_issue_delta = 56,
                added_insights = [
                    '0'
                    ],
                removed_insights = [
                    '0'
                    ],
        )

    def testEmailAuditComparisonDto(self):
        """Test EmailAuditComparisonDto"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from mailslurp_client.api_client import ApiClient
from mailslurp_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class ImapControllerApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def imap_server_fetch(self, seq_num, **kwargs):  # noqa: E501
        """Fetch message in an inbox  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.imap_server_fetch(seq_num, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int seq_num: (required)
        :param str inbox_id: Inbox ID to search
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ImapServerFetchResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.imap_server_fetch_with_http_info(seq_num, **kwargs)  # noqa: E501

    def imap_server_fetch_with_http_info(self, seq_num, **kwargs):  # noqa: E501
        """Fetch message in an inbox  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.imap_server_fetch_with_http_info(seq_num, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int seq_num: (required)
        :param str inbox_id: Inbox ID to search
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ImapServerFetchResult, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'seq_num',
            'inbox_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method imap_server_fetch" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'seq_num' is set
        if self.api_client.client_side_validation and ('seq_num' not in local_var_params or  # noqa: E501
                                                        local_var_params['seq_num'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `seq_num` when calling `imap_server_fetch`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'inbox_id' in local_var_params and local_var_params['inbox_id'] is not None:  # noqa: E501
            query_params.append(('inboxId', local_var_params['inbox_id']))  # noqa: E501
        if 'seq_num' in local_var_params and local_var_params['seq_num'] is not None:  # noqa: E501
            query_params.append(('seqNum', local_var_params['seq_num']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/imap/server/fetch', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ImapServerFetchResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def imap_server_get(self, email_id, **kwargs):  # noqa: E501
        """Get a message by email ID  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.imap_server_get(email_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str email_id: Email ID to get (required)
        :param str inbox_id: Inbox ID to search
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ImapServerGetResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.imap_server_get_with_http_info(email_id, **kwargs)  # noqa: E501

    def imap_server_get_with_http_info(self, email_id, **kwargs):  # noqa: E501
        """Get a message by email ID  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.imap_server_get_with_http_info(email_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str email_id: Email ID to get (required)
        :param str inbox_id: Inbox ID to search
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ImapServerGetResult, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'email_id',
            'inbox_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method imap_server_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'email_id' is set
        if self.api_client.client_side_validation and ('email_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['email_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `email_id` when calling `imap_server_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'email_id' in local_var_params and local_var_params['email_id'] is not None:  # noqa: E501
            query_params.append(('emailId', local_var_params['email_id']))  # noqa: E501
        if 'inbox_id' in local_var_params and local_var_params['inbox_id'] is not None:  # noqa: E501
            query_params.append(('inboxId', local_var_params['inbox_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/imap/server/get', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ImapServerGetResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def imap_server_list(self, imap_server_list_options, **kwargs):  # noqa: E501
        """List messages in an inbox  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.imap_server_list(imap_server_list_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ImapServerListOptions imap_server_list_options: (required)
        :param str inbox_id: Inbox ID to list
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ImapServerListResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.imap_server_list_with_http_info(imap_server_list_options, **kwargs)  # noqa: E501

    def imap_server_list_with_http_info(self, imap_server_list_options, **kwargs):  # noqa: E501
        """List messages in an inbox  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.imap_server_list_with_http_info(imap_server_list_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ImapServerListOptions imap_server_list_options: (required)
        :param str inbox_id: Inbox ID to list
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ImapServerListResult, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'imap_server_list_options',
            'inbox_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method imap_server_list" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'imap_server_list_options' is set
        if self.api_client.client_side_validation and ('imap_server_list_options' not in local_var_params or  # noqa: E501
                                                        local_var_params['imap_server_list_options'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `imap_server_list_options` when calling `imap_server_list`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'inbox_id' in local_var_params and local_var_params['inbox_id'] is not None:  # noqa: E501
            query_params.append(('inboxId', local_var_params['inbox_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'imap_server_list_options' in local_var_params:
            body_params = local_var_params['imap_server_list_options']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/imap/server/list', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ImapServerListResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def imap_server_mailbox(self, name, **kwargs):  # noqa: E501
        """Create a new mailbox if possible  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.imap_server_mailbox(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str name: Inbox email address to create (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ImapServerMailboxResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.imap_server_mailbox_with_http_info(name, **kwargs)  # noqa: E501

    def imap_server_mailbox_with_http_info(self, name, **kwargs):  # noqa: E501
        """Create a new mailbox if possible  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.imap_server_mailbox_with_http_info(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str name: Inbox email address to create (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ImapServerMailboxResult, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'name'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method imap_server_mailbox" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ('name' not in local_var_params or  # noqa: E501
                                                        local_var_params['name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `name` when calling `imap_server_mailbox`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'name' in local_var_params and local_var_params['name'] is not None:  # noqa: E501
            query_params.append(('name', local_var_params['name']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/imap/server/mailbox', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ImapServerMailboxResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def imap_server_search(self, imap_server_search_options, **kwargs):  # noqa: E501
        """Search messages in an inbox  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.imap_server_search(imap_server_search_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ImapServerSearchOptions imap_server_search_options: (required)
        :param str inbox_id: Inbox ID to search
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ImapServerSearchResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.imap_server_search_with_http_info(imap_server_search_options, **kwargs)  # noqa: E501

    def imap_server_search_with_http_info(self, imap_server_search_options, **kwargs):  # noqa: E501
        """Search messages in an inbox  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.imap_server_search_with_http_info(imap_server_search_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ImapServerSearchOptions imap_server_search_options: (required)
        :param str inbox_id: Inbox ID to search
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ImapServerSearchResult, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'imap_server_search_options',
            'inbox_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method imap_server_search" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'imap_server_search_options' is set
        if self.api_client.client_side_validation and ('imap_server_search_options' not in local_var_params or  # noqa: E501
                                                        local_var_params['imap_server_search_options'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `imap_server_search_options` when calling `imap_server_search`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'inbox_id' in local_var_params and local_var_params['inbox_id'] is not None:  # noqa: E501
            query_params.append(('inboxId', local_var_params['inbox_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'imap_server_search_options' in local_var_params:
            body_params = local_var_params['imap_server_search_options']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/imap/server/search', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ImapServerSearchResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def imap_server_status(self, imap_server_status_options, **kwargs):  # noqa: E501
        """Get status for mailbox  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.imap_server_status(imap_server_status_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ImapServerStatusOptions imap_server_status_options: (required)
        :param str inbox_id: Inbox ID to list
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ImapServerStatusResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.imap_server_status_with_http_info(imap_server_status_options, **kwargs)  # noqa: E501

    def imap_server_status_with_http_info(self, imap_server_status_options, **kwargs):  # noqa: E501
        """Get status for mailbox  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.imap_server_status_with_http_info(imap_server_status_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ImapServerStatusOptions imap_server_status_options: (required)
        :param str inbox_id: Inbox ID to list
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ImapServerStatusResult, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'imap_server_status_options',
            'inbox_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method imap_server_status" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'imap_server_status_options' is set
        if self.api_client.client_side_validation and ('imap_server_status_options' not in local_var_params or  # noqa: E501
                                                        local_var_params['imap_server_status_options'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `imap_server_status_options` when calling `imap_server_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'inbox_id' in local_var_params and local_var_params['inbox_id'] is not None:  # noqa: E501
            query_params.append(('inboxId', local_var_params['inbox_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'imap_server_status_options' in local_var_params:
            body_params = local_var_params['imap_server_status_options']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/imap/server/status', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ImapServerStatusResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def imap_server_update_flags(self, imap_update_flags_options, **kwargs):  # noqa: E501
        """imap_server_update_flags  # noqa: E501

        Update message flags  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.imap_server_update_flags(imap_update_flags_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ImapUpdateFlagsOptions imap_update_flags_options: (required)
        :param str inbox_id:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.imap_server_update_flags_with_http_info(imap_update_flags_options, **kwargs)  # noqa: E501

    def imap_server_update_flags_with_http_info(self, imap_update_flags_options, **kwargs):  # noqa: E501
        """imap_server_update_flags  # noqa: E501

        Update message flags  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.imap_server_update_flags_with_http_info(imap_update_flags_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ImapUpdateFlagsOptions imap_update_flags_options: (required)
        :param str inbox_id:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'imap_update_flags_options',
            'inbox_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method imap_server_update_flags" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'imap_update_flags_options' is set
        if self.api_client.client_side_validation and ('imap_update_flags_options' not in local_var_params or  # noqa: E501
                                                        local_var_params['imap_update_flags_options'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `imap_update_flags_options` when calling `imap_server_update_flags`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'inbox_id' in local_var_params and local_var_params['inbox_id'] is not None:  # noqa: E501
            query_params.append(('inboxId', local_var_params['inbox_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'imap_update_flags_options' in local_var_params:
            body_params = local_var_params['imap_update_flags_options']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/imap/server/update-flags', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class EmailIntelligenceResultDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'input': 'str',
        'total_score': 'int',
        'score_breakdown': 'EmailIntelligenceScoreBreakdownDto',
        'signals': 'EmailIntelligenceSignalsDto'
    }

    attribute_map = {
        'input': 'input',
        'total_score': 'totalScore',
        'score_breakdown': 'scoreBreakdown',
        'signals': 'signals'
    }

    def __init__(self, input=None, total_score=None, score_breakdown=None, signals=None, local_vars_configuration=None):  # noqa: E501
        """EmailIntelligenceResultDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._input = None
        self._total_score = None
        self._score_breakdown = None
        self._signals = None
        self.discriminator = None

        self.input = input
        self.total_score = total_score
        self.score_breakdown = score_breakdown
        self.signals = signals

    @property
    def input(self):
        """Gets the input of this EmailIntelligenceResultDto.  # noqa: E501

        Original input value before normalization.  # noqa: E501

        :return: The input of this EmailIntelligenceResultDto.  # noqa: E501
        :rtype: str
        """
        return self._input

    @input.setter
    def input(self, input):
        """Sets the input of this EmailIntelligenceResultDto.

        Original input value before normalization.  # noqa: E501

        :param input: The input of this EmailIntelligenceResultDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and input is None:  # noqa: E501
            raise ValueError("Invalid value for `input`, must not be `None`")  # noqa: E501

        self._input = input

    @property
    def total_score(self):
        """Gets the total_score of this EmailIntelligenceResultDto.  # noqa: E501

        Score from 0 to 100 where higher is better.  # noqa: E501

        :return: The total_score of this EmailIntelligenceResultDto.  # noqa: E501
        :rtype: int
        """
        return self._total_score

    @total_score.setter
    def total_score(self, total_score):
        """Sets the total_score of this EmailIntelligenceResultDto.

        Score from 0 to 100 where higher is better.  # noqa: E501

        :param total_score: The total_score of this EmailIntelligenceResultDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_score is None:  # noqa: E501
            raise ValueError("Invalid value for `total_score`, must not be `None`")  # noqa: E501

        self._total_score = total_score

    @property
    def score_breakdown(self):
        """Gets the score_breakdown of this EmailIntelligenceResultDto.  # noqa: E501


        :return: The score_breakdown of this EmailIntelligenceResultDto.  # noqa: E501
        :rtype: EmailIntelligenceScoreBreakdownDto
        """
        return self._score_breakdown

    @score_breakdown.setter
    def score_breakdown(self, score_breakdown):
        """Sets the score_breakdown of this EmailIntelligenceResultDto.


        :param score_breakdown: The score_breakdown of this EmailIntelligenceResultDto.  # noqa: E501
        :type: EmailIntelligenceScoreBreakdownDto
        """
        if self.local_vars_configuration.client_side_validation and score_breakdown is None:  # noqa: E501
            raise ValueError("Invalid value for `score_breakdown`, must not be `None`")  # noqa: E501

        self._score_breakdown = score_breakdown

    @property
    def signals(self):
        """Gets the signals of this EmailIntelligenceResultDto.  # noqa: E501


        :return: The signals of this EmailIntelligenceResultDto.  # noqa: E501
        :rtype: EmailIntelligenceSignalsDto
        """
        return self._signals

    @signals.setter
    def signals(self, signals):
        """Sets the signals of this EmailIntelligenceResultDto.


        :param signals: The signals of this EmailIntelligenceResultDto.  # noqa: E501
        :type: EmailIntelligenceSignalsDto
        """
        if self.local_vars_configuration.client_side_validation and signals is None:  # noqa: E501
            raise ValueError("Invalid value for `signals`, must not be `None`")  # noqa: E501

        self._signals = signals

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailIntelligenceResultDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EmailIntelligenceResultDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class EmailIntelligenceOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'targets': 'list[str]',
        'page': 'int',
        'size': 'int',
        'ignore_cache': 'bool',
        'include_email_validation': 'bool',
        'tests': 'EmailIntelligenceTestsOptions'
    }

    attribute_map = {
        'targets': 'targets',
        'page': 'page',
        'size': 'size',
        'ignore_cache': 'ignoreCache',
        'include_email_validation': 'includeEmailValidation',
        'tests': 'tests'
    }

    def __init__(self, targets=None, page=None, size=None, ignore_cache=None, include_email_validation=None, tests=None, local_vars_configuration=None):  # noqa: E501
        """EmailIntelligenceOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._targets = None
        self._page = None
        self._size = None
        self._ignore_cache = None
        self._include_email_validation = None
        self._tests = None
        self.discriminator = None

        self.targets = targets
        self.page = page
        self.size = size
        self.ignore_cache = ignore_cache
        self.include_email_validation = include_email_validation
        self.tests = tests

    @property
    def targets(self):
        """Gets the targets of this EmailIntelligenceOptions.  # noqa: E501

        Email addresses or domains to score.  # noqa: E501

        :return: The targets of this EmailIntelligenceOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._targets

    @targets.setter
    def targets(self, targets):
        """Sets the targets of this EmailIntelligenceOptions.

        Email addresses or domains to score.  # noqa: E501

        :param targets: The targets of this EmailIntelligenceOptions.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and targets is None:  # noqa: E501
            raise ValueError("Invalid value for `targets`, must not be `None`")  # noqa: E501

        self._targets = targets

    @property
    def page(self):
        """Gets the page of this EmailIntelligenceOptions.  # noqa: E501

        Zero-based page index for processing a subset of the target list.  # noqa: E501

        :return: The page of this EmailIntelligenceOptions.  # noqa: E501
        :rtype: int
        """
        return self._page

    @page.setter
    def page(self, page):
        """Sets the page of this EmailIntelligenceOptions.

        Zero-based page index for processing a subset of the target list.  # noqa: E501

        :param page: The page of this EmailIntelligenceOptions.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                page is not None and page < 0):  # noqa: E501
            raise ValueError("Invalid value for `page`, must be a value greater than or equal to `0`")  # noqa: E501

        self._page = page

    @property
    def size(self):
        """Gets the size of this EmailIntelligenceOptions.  # noqa: E501

        Page size for processing a subset of the target list.  # noqa: E501

        :return: The size of this EmailIntelligenceOptions.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this EmailIntelligenceOptions.

        Page size for processing a subset of the target list.  # noqa: E501

        :param size: The size of this EmailIntelligenceOptions.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                size is not None and size > 500):  # noqa: E501
            raise ValueError("Invalid value for `size`, must be a value less than or equal to `500`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                size is not None and size < 1):  # noqa: E501
            raise ValueError("Invalid value for `size`, must be a value greater than or equal to `1`")  # noqa: E501

        self._size = size

    @property
    def ignore_cache(self):
        """Gets the ignore_cache of this EmailIntelligenceOptions.  # noqa: E501

        Ignore cached intelligence values and force recomputation.  # noqa: E501

        :return: The ignore_cache of this EmailIntelligenceOptions.  # noqa: E501
        :rtype: bool
        """
        return self._ignore_cache

    @ignore_cache.setter
    def ignore_cache(self, ignore_cache):
        """Sets the ignore_cache of this EmailIntelligenceOptions.

        Ignore cached intelligence values and force recomputation.  # noqa: E501

        :param ignore_cache: The ignore_cache of this EmailIntelligenceOptions.  # noqa: E501
        :type: bool
        """

        self._ignore_cache = ignore_cache

    @property
    def include_email_validation(self):
        """Gets the include_email_validation of this EmailIntelligenceOptions.  # noqa: E501

        Also run mailbox safety verification using the existing verification client for email inputs.  # noqa: E501

        :return: The include_email_validation of this EmailIntelligenceOptions.  # noqa: E501
        :rtype: bool
        """
        return self._include_email_validation

    @include_email_validation.setter
    def include_email_validation(self, include_email_validation):
        """Sets the include_email_validation of this EmailIntelligenceOptions.

        Also run mailbox safety verification using the existing verification client for email inputs.  # noqa: E501

        :param include_email_validation: The include_email_validation of this EmailIntelligenceOptions.  # noqa: E501
        :type: bool
        """

        self._include_email_validation = include_email_validation

    @property
    def tests(self):
        """Gets the tests of this EmailIntelligenceOptions.  # noqa: E501


        :return: The tests of this EmailIntelligenceOptions.  # noqa: E501
        :rtype: EmailIntelligenceTestsOptions
        """
        return self._tests

    @tests.setter
    def tests(self, tests):
        """Sets the tests of this EmailIntelligenceOptions.


        :param tests: The tests of this EmailIntelligenceOptions.  # noqa: E501
        :type: EmailIntelligenceTestsOptions
        """

        self._tests = tests

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailIntelligenceOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EmailIntelligenceOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class EmailIntelligenceSignalsDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'normalized_target': 'str',
        'email_address': 'str',
        'domain': 'str',
        'local_part': 'str',
        'random_local_part': 'bool',
        'local_part_entropy': 'float',
        'free_email_provider': 'bool',
        'has_https_website': 'bool',
        'dns_a_record_present': 'bool',
        'dns_mx_record_present': 'bool',
        'soa_record_present': 'bool',
        'domain_age_hint_days': 'int',
        'never_bounce_safe_to_send': 'bool',
        'notes': 'list[str]'
    }

    attribute_map = {
        'normalized_target': 'normalizedTarget',
        'email_address': 'emailAddress',
        'domain': 'domain',
        'local_part': 'localPart',
        'random_local_part': 'randomLocalPart',
        'local_part_entropy': 'localPartEntropy',
        'free_email_provider': 'freeEmailProvider',
        'has_https_website': 'hasHttpsWebsite',
        'dns_a_record_present': 'dnsARecordPresent',
        'dns_mx_record_present': 'dnsMxRecordPresent',
        'soa_record_present': 'soaRecordPresent',
        'domain_age_hint_days': 'domainAgeHintDays',
        'never_bounce_safe_to_send': 'neverBounceSafeToSend',
        'notes': 'notes'
    }

    def __init__(self, normalized_target=None, email_address=None, domain=None, local_part=None, random_local_part=None, local_part_entropy=None, free_email_provider=None, has_https_website=None, dns_a_record_present=None, dns_mx_record_present=None, soa_record_present=None, domain_age_hint_days=None, never_bounce_safe_to_send=None, notes=None, local_vars_configuration=None):  # noqa: E501
        """EmailIntelligenceSignalsDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._normalized_target = None
        self._email_address = None
        self._domain = None
        self._local_part = None
        self._random_local_part = None
        self._local_part_entropy = None
        self._free_email_provider = None
        self._has_https_website = None
        self._dns_a_record_present = None
        self._dns_mx_record_present = None
        self._soa_record_present = None
        self._domain_age_hint_days = None
        self._never_bounce_safe_to_send = None
        self._notes = None
        self.discriminator = None

        self.normalized_target = normalized_target
        self.email_address = email_address
        self.domain = domain
        self.local_part = local_part
        self.random_local_part = random_local_part
        self.local_part_entropy = local_part_entropy
        self.free_email_provider = free_email_provider
        self.has_https_website = has_https_website
        self.dns_a_record_present = dns_a_record_present
        self.dns_mx_record_present = dns_mx_record_present
        self.soa_record_present = soa_record_present
        self.domain_age_hint_days = domain_age_hint_days
        self.never_bounce_safe_to_send = never_bounce_safe_to_send
        self.notes = notes

    @property
    def normalized_target(self):
        """Gets the normalized_target of this EmailIntelligenceSignalsDto.  # noqa: E501


        :return: The normalized_target of this EmailIntelligenceSignalsDto.  # noqa: E501
        :rtype: str
        """
        return self._normalized_target

    @normalized_target.setter
    def normalized_target(self, normalized_target):
        """Sets the normalized_target of this EmailIntelligenceSignalsDto.


        :param normalized_target: The normalized_target of this EmailIntelligenceSignalsDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and normalized_target is None:  # noqa: E501
            raise ValueError("Invalid value for `normalized_target`, must not be `None`")  # noqa: E501

        self._normalized_target = normalized_target

    @property
    def email_address(self):
        """Gets the email_address of this EmailIntelligenceSignalsDto.  # noqa: E501


        :return: The email_address of this EmailIntelligenceSignalsDto.  # noqa: E501
        :rtype: str
        """
        return self._email_address

    @email_address.setter
    def email_address(self, email_address):
        """Sets the email_address of this EmailIntelligenceSignalsDto.


        :param email_address: The email_address of this EmailIntelligenceSignalsDto.  # noqa: E501
        :type: str
        """

        self._email_address = email_address

    @property
    def domain(self):
        """Gets the domain of this EmailIntelligenceSignalsDto.  # noqa: E501


        :return: The domain of this EmailIntelligenceSignalsDto.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this EmailIntelligenceSignalsDto.


        :param domain: The domain of this EmailIntelligenceSignalsDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and domain is None:  # noqa: E501
            raise ValueError("Invalid value for `domain`, must not be `None`")  # noqa: E501

        self._domain = domain

    @property
    def local_part(self):
        """Gets the local_part of this EmailIntelligenceSignalsDto.  # noqa: E501


        :return: The local_part of this EmailIntelligenceSignalsDto.  # noqa: E501
        :rtype: str
        """
        return self._local_part

    @local_part.setter
    def local_part(self, local_part):
        """Sets the local_part of this EmailIntelligenceSignalsDto.


        :param local_part: The local_part of this EmailIntelligenceSignalsDto.  # noqa: E501
        :type: str
        """

        self._local_part = local_part

    @property
    def random_local_part(self):
        """Gets the random_local_part of this EmailIntelligenceSignalsDto.  # noqa: E501


        :return: The random_local_part of this EmailIntelligenceSignalsDto.  # noqa: E501
        :rtype: bool
        """
        return self._random_local_part

    @random_local_part.setter
    def random_local_part(self, random_local_part):
        """Sets the random_local_part of this EmailIntelligenceSignalsDto.


        :param random_local_part: The random_local_part of this EmailIntelligenceSignalsDto.  # noqa: E501
        :type: bool
        """

        self._random_local_part = random_local_part

    @property
    def local_part_entropy(self):
        """Gets the local_part_entropy of this EmailIntelligenceSignalsDto.  # noqa: E501


        :return: The local_part_entropy of this EmailIntelligenceSignalsDto.  # noqa: E501
        :rtype: float
        """
        return self._local_part_entropy

    @local_part_entropy.setter
    def local_part_entropy(self, local_part_entropy):
        """Sets the local_part_entropy of this EmailIntelligenceSignalsDto.


        :param local_part_entropy: The local_part_entropy of this EmailIntelligenceSignalsDto.  # noqa: E501
        :type: float
        """

        self._local_part_entropy = local_part_entropy

    @property
    def free_email_provider(self):
        """Gets the free_email_provider of this EmailIntelligenceSignalsDto.  # noqa: E501


        :return: The free_email_provider of this EmailIntelligenceSignalsDto.  # noqa: E501
        :rtype: bool
        """
        return self._free_email_provider

    @free_email_provider.setter
    def free_email_provider(self, free_email_provider):
        """Sets the free_email_provider of this EmailIntelligenceSignalsDto.


        :param free_email_provider: The free_email_provider of this EmailIntelligenceSignalsDto.  # noqa: E501
        :type: bool
        """

        self._free_email_provider = free_email_provider

    @property
    def has_https_website(self):
        """Gets the has_https_website of this EmailIntelligenceSignalsDto.  # noqa: E501


        :return: The has_https_website of this EmailIntelligenceSignalsDto.  # noqa: E501
        :rtype: bool
        """
        return self._has_https_website

    @has_https_website.setter
    def has_https_website(self, has_https_website):
        """Sets the has_https_website of this EmailIntelligenceSignalsDto.


        :param has_https_website: The has_https_website of this EmailIntelligenceSignalsDto.  # noqa: E501
        :type: bool
        """

        self._has_https_website = has_https_website

    @property
    def dns_a_record_present(self):
        """Gets the dns_a_record_present of this EmailIntelligenceSignalsDto.  # noqa: E501


        :return: The dns_a_record_present of this EmailIntelligenceSignalsDto.  # noqa: E501
        :rtype: bool
        """
        return self._dns_a_record_present

    @dns_a_record_present.setter
    def dns_a_record_present(self, dns_a_record_present):
        """Sets the dns_a_record_present of this EmailIntelligenceSignalsDto.


        :param dns_a_record_present: The dns_a_record_present of this EmailIntelligenceSignalsDto.  # noqa: E501
        :type: bool
        """

        self._dns_a_record_present = dns_a_record_present

    @property
    def dns_mx_record_present(self):
        """Gets the dns_mx_record_present of this EmailIntelligenceSignalsDto.  # noqa: E501


        :return: The dns_mx_record_present of this EmailIntelligenceSignalsDto.  # noqa: E501
        :rtype: bool
        """
        return self._dns_mx_record_present

    @dns_mx_record_present.setter
    def dns_mx_record_present(self, dns_mx_record_present):
        """Sets the dns_mx_record_present of this EmailIntelligenceSignalsDto.


        :param dns_mx_record_present: The dns_mx_record_present of this EmailIntelligenceSignalsDto.  # noqa: E501
        :type: bool
        """

        self._dns_mx_record_present = dns_mx_record_present

    @property
    def soa_record_present(self):
        """Gets the soa_record_present of this EmailIntelligenceSignalsDto.  # noqa: E501


        :return: The soa_record_present of this EmailIntelligenceSignalsDto.  # noqa: E501
        :rtype: bool
        """
        return self._soa_record_present

    @soa_record_present.setter
    def soa_record_present(self, soa_record_present):
        """Sets the soa_record_present of this EmailIntelligenceSignalsDto.


        :param soa_record_present: The soa_record_present of this EmailIntelligenceSignalsDto.  # noqa: E501
        :type: bool
        """

        self._soa_record_present = soa_record_present

    @property
    def domain_age_hint_days(self):
        """Gets the domain_age_hint_days of this EmailIntelligenceSignalsDto.  # noqa: E501


        :return: The domain_age_hint_days of this EmailIntelligenceSignalsDto.  # noqa: E501
        :rtype: int
        """
        return self._domain_age_hint_days

    @domain_age_hint_days.setter
    def domain_age_hint_days(self, domain_age_hint_days):
        """Sets the domain_age_hint_days of this EmailIntelligenceSignalsDto.


        :param domain_age_hint_days: The domain_age_hint_days of this EmailIntelligenceSignalsDto.  # noqa: E501
        :type: int
        """

        self._domain_age_hint_days = domain_age_hint_days

    @property
    def never_bounce_safe_to_send(self):
        """Gets the never_bounce_safe_to_send of this EmailIntelligenceSignalsDto.  # noqa: E501


        :return: The never_bounce_safe_to_send of this EmailIntelligenceSignalsDto.  # noqa: E501
        :rtype: bool
        """
        return self._never_bounce_safe_to_send

    @never_bounce_safe_to_send.setter
    def never_bounce_safe_to_send(self, never_bounce_safe_to_send):
        """Sets the never_bounce_safe_to_send of this EmailIntelligenceSignalsDto.


        :param never_bounce_safe_to_send: The never_bounce_safe_to_send of this EmailIntelligenceSignalsDto.  # noqa: E501
        :type: bool
        """

        self._never_bounce_safe_to_send = never_bounce_safe_to_send

    @property
    def notes(self):
        """Gets the notes of this EmailIntelligenceSignalsDto.  # noqa: E501


        :return: The notes of this EmailIntelligenceSignalsDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._notes

    @notes.setter
    def notes(self, notes):
        """Sets the notes of this EmailIntelligenceSignalsDto.


        :param notes: The notes of this EmailIntelligenceSignalsDto.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and notes is None:  # noqa: E501
            raise ValueError("Invalid value for `notes`, must not be `None`")  # noqa: E501

        self._notes = notes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailIntelligenceSignalsDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EmailIntelligenceSignalsDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.imap_controller_api import ImapControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestImapControllerApi(unittest.TestCase):
    """ImapControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.imap_controller_api.ImapControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_imap_server_fetch(self):
        """Test case for imap_server_fetch

        Fetch message in an inbox  # noqa: E501
        """
        pass

    def test_imap_server_get(self):
        """Test case for imap_server_get

        Get a message by email ID  # noqa: E501
        """
        pass

    def test_imap_server_list(self):
        """Test case for imap_server_list

        List messages in an inbox  # noqa: E501
        """
        pass

    def test_imap_server_mailbox(self):
        """Test case for imap_server_mailbox

        Create a new mailbox if possible  # noqa: E501
        """
        pass

    def test_imap_server_search(self):
        """Test case for imap_server_search

        Search messages in an inbox  # noqa: E501
        """
        pass

    def test_imap_server_status(self):
        """Test case for imap_server_status

        Get status for mailbox  # noqa: E501
        """
        pass

    def test_imap_server_update_flags(self):
        """Test case for imap_server_update_flags

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CheckDomainMonitorResults(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'domain': 'str',
        'status': 'str',
        'health_score': 'int',
        'total_checks': 'int',
        'passing_checks': 'int',
        'failing_checks': 'int',
        'spf_ok': 'bool',
        'dmarc_ok': 'bool',
        'dmarc_enforced': 'bool',
        'mx_ok': 'bool',
        'insights': 'list[str]',
        'error_message': 'str'
    }

    attribute_map = {
        'domain': 'domain',
        'status': 'status',
        'health_score': 'healthScore',
        'total_checks': 'totalChecks',
        'passing_checks': 'passingChecks',
        'failing_checks': 'failingChecks',
        'spf_ok': 'spfOk',
        'dmarc_ok': 'dmarcOk',
        'dmarc_enforced': 'dmarcEnforced',
        'mx_ok': 'mxOk',
        'insights': 'insights',
        'error_message': 'errorMessage'
    }

    def __init__(self, domain=None, status=None, health_score=None, total_checks=None, passing_checks=None, failing_checks=None, spf_ok=None, dmarc_ok=None, dmarc_enforced=None, mx_ok=None, insights=None, error_message=None, local_vars_configuration=None):  # noqa: E501
        """CheckDomainMonitorResults - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._domain = None
        self._status = None
        self._health_score = None
        self._total_checks = None
        self._passing_checks = None
        self._failing_checks = None
        self._spf_ok = None
        self._dmarc_ok = None
        self._dmarc_enforced = None
        self._mx_ok = None
        self._insights = None
        self._error_message = None
        self.discriminator = None

        self.domain = domain
        self.status = status
        self.health_score = health_score
        self.total_checks = total_checks
        self.passing_checks = passing_checks
        self.failing_checks = failing_checks
        self.spf_ok = spf_ok
        self.dmarc_ok = dmarc_ok
        self.dmarc_enforced = dmarc_enforced
        self.mx_ok = mx_ok
        self.insights = insights
        self.error_message = error_message

    @property
    def domain(self):
        """Gets the domain of this CheckDomainMonitorResults.  # noqa: E501


        :return: The domain of this CheckDomainMonitorResults.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this CheckDomainMonitorResults.


        :param domain: The domain of this CheckDomainMonitorResults.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and domain is None:  # noqa: E501
            raise ValueError("Invalid value for `domain`, must not be `None`")  # noqa: E501

        self._domain = domain

    @property
    def status(self):
        """Gets the status of this CheckDomainMonitorResults.  # noqa: E501


        :return: The status of this CheckDomainMonitorResults.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this CheckDomainMonitorResults.


        :param status: The status of this CheckDomainMonitorResults.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["HEALTHY", "DEGRADED", "CRITICAL", "FAILED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def health_score(self):
        """Gets the health_score of this CheckDomainMonitorResults.  # noqa: E501


        :return: The health_score of this CheckDomainMonitorResults.  # noqa: E501
        :rtype: int
        """
        return self._health_score

    @health_score.setter
    def health_score(self, health_score):
        """Sets the health_score of this CheckDomainMonitorResults.


        :param health_score: The health_score of this CheckDomainMonitorResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and health_score is None:  # noqa: E501
            raise ValueError("Invalid value for `health_score`, must not be `None`")  # noqa: E501

        self._health_score = health_score

    @property
    def total_checks(self):
        """Gets the total_checks of this CheckDomainMonitorResults.  # noqa: E501


        :return: The total_checks of this CheckDomainMonitorResults.  # noqa: E501
        :rtype: int
        """
        return self._total_checks

    @total_checks.setter
    def total_checks(self, total_checks):
        """Sets the total_checks of this CheckDomainMonitorResults.


        :param total_checks: The total_checks of this CheckDomainMonitorResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_checks is None:  # noqa: E501
            raise ValueError("Invalid value for `total_checks`, must not be `None`")  # noqa: E501

        self._total_checks = total_checks

    @property
    def passing_checks(self):
        """Gets the passing_checks of this CheckDomainMonitorResults.  # noqa: E501


        :return: The passing_checks of this CheckDomainMonitorResults.  # noqa: E501
        :rtype: int
        """
        return self._passing_checks

    @passing_checks.setter
    def passing_checks(self, passing_checks):
        """Sets the passing_checks of this CheckDomainMonitorResults.


        :param passing_checks: The passing_checks of this CheckDomainMonitorResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and passing_checks is None:  # noqa: E501
            raise ValueError("Invalid value for `passing_checks`, must not be `None`")  # noqa: E501

        self._passing_checks = passing_checks

    @property
    def failing_checks(self):
        """Gets the failing_checks of this CheckDomainMonitorResults.  # noqa: E501


        :return: The failing_checks of this CheckDomainMonitorResults.  # noqa: E501
        :rtype: int
        """
        return self._failing_checks

    @failing_checks.setter
    def failing_checks(self, failing_checks):
        """Sets the failing_checks of this CheckDomainMonitorResults.


        :param failing_checks: The failing_checks of this CheckDomainMonitorResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and failing_checks is None:  # noqa: E501
            raise ValueError("Invalid value for `failing_checks`, must not be `None`")  # noqa: E501

        self._failing_checks = failing_checks

    @property
    def spf_ok(self):
        """Gets the spf_ok of this CheckDomainMonitorResults.  # noqa: E501


        :return: The spf_ok of this CheckDomainMonitorResults.  # noqa: E501
        :rtype: bool
        """
        return self._spf_ok

    @spf_ok.setter
    def spf_ok(self, spf_ok):
        """Sets the spf_ok of this CheckDomainMonitorResults.


        :param spf_ok: The spf_ok of this CheckDomainMonitorResults.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and spf_ok is None:  # noqa: E501
            raise ValueError("Invalid value for `spf_ok`, must not be `None`")  # noqa: E501

        self._spf_ok = spf_ok

    @property
    def dmarc_ok(self):
        """Gets the dmarc_ok of this CheckDomainMonitorResults.  # noqa: E501


        :return: The dmarc_ok of this CheckDomainMonitorResults.  # noqa: E501
        :rtype: bool
        """
        return self._dmarc_ok

    @dmarc_ok.setter
    def dmarc_ok(self, dmarc_ok):
        """Sets the dmarc_ok of this CheckDomainMonitorResults.


        :param dmarc_ok: The dmarc_ok of this CheckDomainMonitorResults.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and dmarc_ok is None:  # noqa: E501
            raise ValueError("Invalid value for `dmarc_ok`, must not be `None`")  # noqa: E501

        self._dmarc_ok = dmarc_ok

    @property
    def dmarc_enforced(self):
        """Gets the dmarc_enforced of this CheckDomainMonitorResults.  # noqa: E501


        :return: The dmarc_enforced of this CheckDomainMonitorResults.  # noqa: E501
        :rtype: bool
        """
        return self._dmarc_enforced

    @dmarc_enforced.setter
    def dmarc_enforced(self, dmarc_enforced):
        """Sets the dmarc_enforced of this CheckDomainMonitorResults.


        :param dmarc_enforced: The dmarc_enforced of this CheckDomainMonitorResults.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and dmarc_enforced is None:  # noqa: E501
            raise ValueError("Invalid value for `dmarc_enforced`, must not be `None`")  # noqa: E501

        self._dmarc_enforced = dmarc_enforced

    @property
    def mx_ok(self):
        """Gets the mx_ok of this CheckDomainMonitorResults.  # noqa: E501


        :return: The mx_ok of this CheckDomainMonitorResults.  # noqa: E501
        :rtype: bool
        """
        return self._mx_ok

    @mx_ok.setter
    def mx_ok(self, mx_ok):
        """Sets the mx_ok of this CheckDomainMonitorResults.


        :param mx_ok: The mx_ok of this CheckDomainMonitorResults.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and mx_ok is None:  # noqa: E501
            raise ValueError("Invalid value for `mx_ok`, must not be `None`")  # noqa: E501

        self._mx_ok = mx_ok

    @property
    def insights(self):
        """Gets the insights of this CheckDomainMonitorResults.  # noqa: E501


        :return: The insights of this CheckDomainMonitorResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._insights

    @insights.setter
    def insights(self, insights):
        """Sets the insights of this CheckDomainMonitorResults.


        :param insights: The insights of this CheckDomainMonitorResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and insights is None:  # noqa: E501
            raise ValueError("Invalid value for `insights`, must not be `None`")  # noqa: E501

        self._insights = insights

    @property
    def error_message(self):
        """Gets the error_message of this CheckDomainMonitorResults.  # noqa: E501


        :return: The error_message of this CheckDomainMonitorResults.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this CheckDomainMonitorResults.


        :param error_message: The error_message of this CheckDomainMonitorResults.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CheckDomainMonitorResults):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CheckDomainMonitorResults):
            return True

        return self.to_dict() != other.to_dict()
